Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Equal ¶
Equal checks if two objects of any type are equal and reports an error if they are not.
func MustEqual ¶
MustEqual asserts that two objects are equal and stops test execution if they are not.
func MustNotEqual ¶
MustNotEqual asserts that two objects are not equal and stops test execution if they are not.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.